
Extraneous files in document root
-------

**Description:**

Whenever the document root contains extraneous files, these files could be accessed by an 
attacker or could possibly contain functionality witch could contain other vulnerabilities.


**Solution:**

Extraneous files in document root should be investigated and deleted if it's not necessary 
for operation of the application.

	
